@@ -23,6 +23,7 @@
 
 #include <gst/gst.h>
 #include <gst/video/video.h>
+#include <gst/video/gstvideoencoder.h>
 #include "_stdint.h"
 #include <x264.h>
 
@@ -44,17 +45,17 @@ typedef struct _GstX264EncClass GstX264EncClass;
 
 struct _GstX264Enc
 {
-  GstElement element;
+  GstVideoEncoder element;
 
   /*< private >*/
-  GstPad *sinkpad;
-  GstPad *srcpad;
-  GstSegment segment;
-
   x264_t *x264enc;
   x264_param_t x264param;
   gint current_byte_stream;
 
+  /* List of frame/buffer mapping structs for
+   * pending frames */
+  GList *pending_frames;
+
   /* properties */
   guint threads;
   gboolean sliced_threads;
@@ -97,13 +98,7 @@ struct _GstX264Enc
   GString *option_string; /* used by set prop */
 
   /* input description */
-  GstVideoInfo info;
-
-  /* for b-frame delay handling */
-  GQueue *delay;
-
-  guint8 *buffer;
-  gulong buffer_size;
+  GstVideoCodecState *input_state;
 
   /* configuration changed  while playing */
   gboolean reconfig;
@@ -112,14 +107,11 @@ struct _GstX264Enc
   const gchar *peer_profile;
   gboolean peer_intra_profile;
   const x264_level_t *peer_level;
-
-  GstClockTime pending_key_unit_ts;
-  GstEvent *force_key_unit_event;
 };
 
 struct _GstX264EncClass
 {
-  GstElementClass parent_class;
+  GstVideoEncoderClass parent_class;
 };
 
 GType gst_x264_enc_get_type (void);
